============
Data Sources
============

PySUS allows you to download data on demand from DATASUS databases.
Currently, the following databases can be downloaded:

#. SINAN
#. SINASC
#. SIM
#. SIH
#. SIA
